==> component-dev-tools-0.0.4.tgz: package/es/manager/base/template.js <==
#!/usr/bin/env node
import c from "lodash.template";
import h from "lodash.get";
import F from "lodash.lowerfirst";
import P from "chalk";
import { readFileSync as d } from "node:fs";
import { join as t } from "node:path";
import { rootPath as l, configRootPath as f } from "./path.config.js";
const v = (o, r, i) => {
  const p = {
    ...r,
    src: o.src,
    srcExample: o.srcExample,
    nameLowerFirst: F(r.name),
    $: "$"
  }, e = i.reduce(
    (m, n) => {
      let a = h(o, n);
      if (n.endsWith(".templateFilePath")) {
        const y = t(
          l,
          f,
          a
        );
        a = d(y, "utf-8");
      }
      const s = c(a);
      return m[n] = s(p), console.log(
        P.green(
          `${n}模板解析完成${Array(50 - n.length).fill("").join("_")}`
        )
      ), m;
    },
    {}
  );
  return {
    componentDirPath: t(l, e["component.dir"]),
    componentFileContent: e["component.templateFilePath"],
    componentFilePath: t(
      l,
      e["component.dir"],
      e["component.fileName"]
    ),
    componentEntryFileAddContent: e["component.entryTemplate"],
    componentEntryFilePath: t(l, e["component.entryPath"]),
    styleDirPath: t(l, e["style.dir"]),
    styleFileContent: e["style.templateFilePath"],
    styleFilePath: t(l, e["style.dir"], e["style.fileName"]),
    styleVarFileAddContent: e["style.varTemplate"],
    styleVarFilePath: t(l, e["style.varPath"]),
    styleEntryFileAddContent: e["style.entryTemplate"],
    styleEntryFilePath: t(l, e["style.entryPath"]),
    exampleDirPath: t(l, e["example.dir"]),
    exampleFileContent: e["example.templateFilePath"],
    exampleFilePath: t(
      l,
      e["example.dir"],
      e["example.fileName"]
    ),
    exampleEntryFileAddContent: e["example.entryTemplate"],
    exampleEntryFilePath: t(l, e["example.entryPath"])
  };
};
export {
  v as resolveTemplate
};

==> component-dev-tools-0.0.7.tgz: package/es/manager/base/template.js <==
#!/usr/bin/env node
import s from "lodash.template";
import F from "lodash.get";
import P from "lodash.lowerfirst";
import c from "chalk";
import { readFileSync as d } from "node:fs";
import { join as t } from "node:path";
import { rootPath as l, configRootPath as f } from "./path.config.js";
const v = (a, r, i) => {
  const p = {
    ...r,
    src: a.src,
    srcExample: a.srcExample,
    nameLowerFirst: P(r.name),
    $: "$"
  }, e = i.reduce(
    (m, n) => {
      let o = F(a, n);
      if (n.endsWith(".templateFilePath")) {
        const h = t(
          l,
          f,
          o
        );
        o = d(h, "utf-8");
      }
      const y = s(o);
      return m[n] = y(p), console.log(
        c.green(
          `${n}模板解析完成${Array(50 - n.length).fill("").join("_")}`
        )
      ), m;
    },
    {}
  );
  return {
    componentDirPath: t(l, e["component.dir"]),
    componentFileContent: e["component.templateFilePath"],
    componentFilePath: t(
      l,
      e["component.dir"],
      e["component.fileName"]
    ),
    componentEntryFileAddContent: e["component.entryTemplate"],
    componentEntryFilePath: t(l, e["component.entryPath"]),
    typeDirPath: t(l, e["type.dir"]),
    typeFileContent: e["type.templateFilePath"],
    typeFilePath: t(l, e["type.dir"], e["type.fileName"]),
    typeEntryFileAddContent: e["type.entryTemplate"],
    typeEntryFilePath: t(l, e["type.entryPath"]),
    styleDirPath: t(l, e["style.dir"]),
    styleFileContent: e["style.templateFilePath"],
    styleFilePath: t(l, e["style.dir"], e["style.fileName"]),
    styleVarFileAddContent: e["style.varTemplate"],
    styleVarFilePath: t(l, e["style.varPath"]),
    styleEntryFileAddContent: e["style.entryTemplate"],
    styleEntryFilePath: t(l, e["style.entryPath"]),
    exampleDirPath: t(l, e["example.dir"]),
    exampleFileContent: e["example.templateFilePath"],
    exampleFilePath: t(
      l,
      e["example.dir"],
      e["example.fileName"]
    ),
    exampleEntryFileAddContent: e["example.entryTemplate"],
    exampleEntryFilePath: t(l, e["example.entryPath"])
  };
};
export {
  v as resolveTemplate
};
